# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'openpiv/data/ui/mainwindow.ui'
#
# Created: Fri Apr 25 11:33:15 2014
#      by: pyside-uic 0.2.14 running on PySide 1.2.1
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore, QtGui

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(815, 650)
        MainWindow.setMinimumSize(QtCore.QSize(815, 650))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("images/urapiv_icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridlayout = QtGui.QGridLayout(self.centralwidget)
        self.gridlayout.setObjectName("gridlayout")
        self.hboxlayout = QtGui.QHBoxLayout()
        self.hboxlayout.setObjectName("hboxlayout")
        self.vboxlayout = QtGui.QVBoxLayout()
        self.vboxlayout.setObjectName("vboxlayout")
        self.topCombo = QtGui.QComboBox(self.centralwidget)
        self.topCombo.setObjectName("topCombo")
        self.vboxlayout.addWidget(self.topCombo)
        self.topGraphicsView = QtGui.QGraphicsView(self.centralwidget)
        self.topGraphicsView.setMinimumSize(QtCore.QSize(250, 200))
        self.topGraphicsView.setObjectName("topGraphicsView")
        self.vboxlayout.addWidget(self.topGraphicsView)
        self.bottomCombo = QtGui.QComboBox(self.centralwidget)
        self.bottomCombo.setObjectName("bottomCombo")
        self.vboxlayout.addWidget(self.bottomCombo)
        self.statsTable = QtGui.QTableWidget(self.centralwidget)
        self.statsTable.setMinimumSize(QtCore.QSize(250, 200))
        self.statsTable.setDragDropOverwriteMode(False)
        self.statsTable.setSelectionMode(QtGui.QAbstractItemView.NoSelection)
        self.statsTable.setObjectName("statsTable")
        self.statsTable.setColumnCount(0)
        self.statsTable.setRowCount(0)
        self.vboxlayout.addWidget(self.statsTable)
        self.hboxlayout.addLayout(self.vboxlayout)
        self.vboxlayout1 = QtGui.QVBoxLayout()
        self.vboxlayout1.setObjectName("vboxlayout1")
        self.hboxlayout1 = QtGui.QHBoxLayout()
        self.hboxlayout1.setObjectName("hboxlayout1")
        self.aFrameButton = QtGui.QPushButton(self.centralwidget)
        self.aFrameButton.setCheckable(True)
        self.aFrameButton.setChecked(False)
        self.aFrameButton.setObjectName("aFrameButton")
        self.hboxlayout1.addWidget(self.aFrameButton)
        self.bFrameButton = QtGui.QPushButton(self.centralwidget)
        self.bFrameButton.setCheckable(True)
        self.bFrameButton.setObjectName("bFrameButton")
        self.hboxlayout1.addWidget(self.bFrameButton)
        spacerItem = QtGui.QSpacerItem(181, 27, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.hboxlayout1.addItem(spacerItem)
        self.redrawButton = QtGui.QPushButton(self.centralwidget)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("../../../../../../.designer/backup"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.redrawButton.setIcon(icon1)
        self.redrawButton.setObjectName("redrawButton")
        self.hboxlayout1.addWidget(self.redrawButton)
        self.vboxlayout1.addLayout(self.hboxlayout1)
        self.graphicsView = QtGui.QGraphicsView(self.centralwidget)
        self.graphicsView.setObjectName("graphicsView")
        self.vboxlayout1.addWidget(self.graphicsView)
        self.hboxlayout2 = QtGui.QHBoxLayout()
        self.hboxlayout2.setObjectName("hboxlayout2")
        self.startButton = QtGui.QToolButton(self.centralwidget)
        self.startButton.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap("../../../../../../.designer/backup"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon2.addPixmap(QtGui.QPixmap(":/icons/icons/player_start.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.startButton.setIcon(icon2)
        self.startButton.setIconSize(QtCore.QSize(32, 32))
        self.startButton.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.startButton.setAutoRaise(True)
        self.startButton.setObjectName("startButton")
        self.hboxlayout2.addWidget(self.startButton)
        self.backButton = QtGui.QToolButton(self.centralwidget)
        self.backButton.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap("../../../../../../.designer/backup"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon3.addPixmap(QtGui.QPixmap(":/icons/icons/player_rew.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.backButton.setIcon(icon3)
        self.backButton.setIconSize(QtCore.QSize(32, 32))
        self.backButton.setAutoRaise(True)
        self.backButton.setObjectName("backButton")
        self.hboxlayout2.addWidget(self.backButton)
        self.frameSpinBox = QtGui.QSpinBox(self.centralwidget)
        self.frameSpinBox.setMinimumSize(QtCore.QSize(80, 0))
        self.frameSpinBox.setMaximumSize(QtCore.QSize(100, 16777215))
        self.frameSpinBox.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.frameSpinBox.setMaximum(99999)
        self.frameSpinBox.setObjectName("frameSpinBox")
        self.hboxlayout2.addWidget(self.frameSpinBox)
        self.forwardButton = QtGui.QToolButton(self.centralwidget)
        self.forwardButton.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap("../../../../../../.designer/backup"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon4.addPixmap(QtGui.QPixmap(":/icons/icons/player_fwd.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.forwardButton.setIcon(icon4)
        self.forwardButton.setIconSize(QtCore.QSize(32, 32))
        self.forwardButton.setAutoRaise(True)
        self.forwardButton.setObjectName("forwardButton")
        self.hboxlayout2.addWidget(self.forwardButton)
        self.endButton = QtGui.QToolButton(self.centralwidget)
        self.endButton.setAutoFillBackground(False)
        self.endButton.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap("../../../../../../.designer/backup"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon5.addPixmap(QtGui.QPixmap(":/icons/icons/player_end.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.endButton.setIcon(icon5)
        self.endButton.setIconSize(QtCore.QSize(32, 32))
        self.endButton.setAutoRaise(True)
        self.endButton.setObjectName("endButton")
        self.hboxlayout2.addWidget(self.endButton)
        self.vboxlayout1.addLayout(self.hboxlayout2)
        self.hboxlayout.addLayout(self.vboxlayout1)
        self.gridlayout.addLayout(self.hboxlayout, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar()
        self.menubar.setGeometry(QtCore.QRect(0, 0, 815, 25))
        self.menubar.setObjectName("menubar")
        self.menuNew = QtGui.QMenu(self.menubar)
        self.menuNew.setObjectName("menuNew")
        self.menuView = QtGui.QMenu(self.menubar)
        self.menuView.setObjectName("menuView")
        self.menuTools = QtGui.QMenu(self.menubar)
        self.menuTools.setObjectName("menuTools")
        self.menuHelp = QtGui.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.toolBar = QtGui.QToolBar(MainWindow)
        self.toolBar.setWhatsThis("")
        self.toolBar.setMovable(False)
        self.toolBar.setObjectName("toolBar")
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.actionNew = QtGui.QAction(MainWindow)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap("icons/filenew.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon6.addPixmap(QtGui.QPixmap(":/icons/icons/filenew.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.actionNew.setIcon(icon6)
        self.actionNew.setIconVisibleInMenu(True)
        self.actionNew.setObjectName("actionNew")
        self.actionOpen = QtGui.QAction(MainWindow)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap("icons/fileopen.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon7.addPixmap(QtGui.QPixmap(":/icons/icons/fileopen.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.actionOpen.setIcon(icon7)
        self.actionOpen.setObjectName("actionOpen")
        self.actionSave = QtGui.QAction(MainWindow)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap("icons/filesave.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon8.addPixmap(QtGui.QPixmap(":/icons/icons/filesave.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.actionSave.setIcon(icon8)
        self.actionSave.setObjectName("actionSave")
        self.actionSaveAs = QtGui.QAction(MainWindow)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap("icons/filesaveas.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSaveAs.setIcon(icon9)
        self.actionSaveAs.setObjectName("actionSaveAs")
        self.actionPlay = QtGui.QAction(MainWindow)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap("icons/player_play.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPlay.setIcon(icon10)
        self.actionPlay.setObjectName("actionPlay")
        self.actionFF = QtGui.QAction(MainWindow)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap("icons/player_fwd.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFF.setIcon(icon11)
        self.actionFF.setObjectName("actionFF")
        self.actionFullFF = QtGui.QAction(MainWindow)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap("icons/player_end.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFullFF.setIcon(icon12)
        self.actionFullFF.setObjectName("actionFullFF")
        self.actionPause = QtGui.QAction(MainWindow)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap("icons/player_pause.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPause.setIcon(icon13)
        self.actionPause.setObjectName("actionPause")
        self.actionRW = QtGui.QAction(MainWindow)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap("icons/player_rew.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionRW.setIcon(icon14)
        self.actionRW.setObjectName("actionRW")
        self.actionFullRW = QtGui.QAction(MainWindow)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap("icons/player_start.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFullRW.setIcon(icon15)
        self.actionFullRW.setObjectName("actionFullRW")
        self.actionHelp = QtGui.QAction(MainWindow)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap("icons/help.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionHelp.setIcon(icon16)
        self.actionHelp.setObjectName("actionHelp")
        self.actionAbput = QtGui.QAction(MainWindow)
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/icons/icons/help.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionAbput.setIcon(icon17)
        self.actionAbput.setObjectName("actionAbput")
        self.actionSetup = QtGui.QAction(MainWindow)
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap("icons/configure.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon18.addPixmap(QtGui.QPixmap(":/icons/icons/configure.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.actionSetup.setIcon(icon18)
        self.actionSetup.setObjectName("actionSetup")
        self.actionImageIn = QtGui.QAction(MainWindow)
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap("icons/import_image.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon19.addPixmap(QtGui.QPixmap(":/icons/icons/import_image.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.actionImageIn.setIcon(icon19)
        self.actionImageIn.setObjectName("actionImageIn")
        self.actionImportVector = QtGui.QAction(MainWindow)
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap("icons/import_vector.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionImportVector.setIcon(icon20)
        self.actionImportVector.setObjectName("actionImportVector")
        self.actionQuit = QtGui.QAction(MainWindow)
        icon21 = QtGui.QIcon()
        icon21.addPixmap(QtGui.QPixmap("icons/exit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionQuit.setIcon(icon21)
        self.actionQuit.setObjectName("actionQuit")
        self.actionZoomIn = QtGui.QAction(MainWindow)
        icon22 = QtGui.QIcon()
        icon22.addPixmap(QtGui.QPixmap("icons/viewmag+.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon22.addPixmap(QtGui.QPixmap(":/icons/icons/viewmag+.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.actionZoomIn.setIcon(icon22)
        self.actionZoomIn.setObjectName("actionZoomIn")
        self.actionZoomOut = QtGui.QAction(MainWindow)
        icon23 = QtGui.QIcon()
        icon23.addPixmap(QtGui.QPixmap("icons/viewmag-.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon23.addPixmap(QtGui.QPixmap(":/icons/icons/viewmag-.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.actionZoomOut.setIcon(icon23)
        self.actionZoomOut.setObjectName("actionZoomOut")
        self.actionProcessImages = QtGui.QAction(MainWindow)
        icon24 = QtGui.QIcon()
        icon24.addPixmap(QtGui.QPixmap("icons/kcmsystem.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon24.addPixmap(QtGui.QPixmap(":/icons/icons/kcmsystem.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.actionProcessImages.setIcon(icon24)
        self.actionProcessImages.setObjectName("actionProcessImages")
        self.actionFilterSet = QtGui.QAction(MainWindow)
        icon25 = QtGui.QIcon()
        icon25.addPixmap(QtGui.QPixmap("icons/filtersettings.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon25.addPixmap(QtGui.QPixmap(":/icons/icons/filtersettings.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.actionFilterSet.setIcon(icon25)
        self.actionFilterSet.setObjectName("actionFilterSet")
        self.actionFilter = QtGui.QAction(MainWindow)
        icon26 = QtGui.QIcon()
        icon26.addPixmap(QtGui.QPixmap("icons/filter.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon26.addPixmap(QtGui.QPixmap(":/icons/icons/filter.png"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.actionFilter.setIcon(icon26)
        self.actionFilter.setObjectName("actionFilter")
        self.menuNew.addAction(self.actionNew)
        self.menuNew.addAction(self.actionOpen)
        self.menuNew.addAction(self.actionSave)
        self.menuNew.addAction(self.actionSaveAs)
        self.menuNew.addSeparator()
        self.menuNew.addAction(self.actionQuit)
        self.menuView.addAction(self.actionZoomIn)
        self.menuView.addAction(self.actionZoomOut)
        self.menuTools.addAction(self.actionImageIn)
        self.menuTools.addAction(self.actionSetup)
        self.menuTools.addAction(self.actionProcessImages)
        self.menuHelp.addAction(self.actionHelp)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionAbput)
        self.menubar.addAction(self.menuNew.menuAction())
        self.menubar.addAction(self.menuView.menuAction())
        self.menubar.addAction(self.menuTools.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.toolBar.addAction(self.actionNew)
        self.toolBar.addAction(self.actionOpen)
        self.toolBar.addAction(self.actionSave)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionImageIn)
        self.toolBar.addAction(self.actionZoomIn)
        self.toolBar.addAction(self.actionZoomOut)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionSetup)
        self.toolBar.addAction(self.actionProcessImages)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionFilterSet)
        self.toolBar.addAction(self.actionFilter)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "OpenPiv", None, QtGui.QApplication.UnicodeUTF8))
        self.aFrameButton.setText(QtGui.QApplication.translate("MainWindow", "Frame A", None, QtGui.QApplication.UnicodeUTF8))
        self.bFrameButton.setText(QtGui.QApplication.translate("MainWindow", "Frame B", None, QtGui.QApplication.UnicodeUTF8))
        self.redrawButton.setText(QtGui.QApplication.translate("MainWindow", "Redraw", None, QtGui.QApplication.UnicodeUTF8))
        self.menuNew.setTitle(QtGui.QApplication.translate("MainWindow", "File", None, QtGui.QApplication.UnicodeUTF8))
        self.menuView.setTitle(QtGui.QApplication.translate("MainWindow", "View", None, QtGui.QApplication.UnicodeUTF8))
        self.menuTools.setTitle(QtGui.QApplication.translate("MainWindow", "Tools", None, QtGui.QApplication.UnicodeUTF8))
        self.menuHelp.setTitle(QtGui.QApplication.translate("MainWindow", "Help", None, QtGui.QApplication.UnicodeUTF8))
        self.toolBar.setWindowTitle(QtGui.QApplication.translate("MainWindow", "toolBar", None, QtGui.QApplication.UnicodeUTF8))
        self.actionNew.setText(QtGui.QApplication.translate("MainWindow", "New...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionOpen.setText(QtGui.QApplication.translate("MainWindow", "Open...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave.setText(QtGui.QApplication.translate("MainWindow", "Save", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSaveAs.setText(QtGui.QApplication.translate("MainWindow", "Save As...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionPlay.setText(QtGui.QApplication.translate("MainWindow", "Play", None, QtGui.QApplication.UnicodeUTF8))
        self.actionFF.setText(QtGui.QApplication.translate("MainWindow", "FF", None, QtGui.QApplication.UnicodeUTF8))
        self.actionFullFF.setText(QtGui.QApplication.translate("MainWindow", "FullFF", None, QtGui.QApplication.UnicodeUTF8))
        self.actionPause.setText(QtGui.QApplication.translate("MainWindow", "Pause", None, QtGui.QApplication.UnicodeUTF8))
        self.actionRW.setText(QtGui.QApplication.translate("MainWindow", "RW", None, QtGui.QApplication.UnicodeUTF8))
        self.actionFullRW.setText(QtGui.QApplication.translate("MainWindow", "FullRW", None, QtGui.QApplication.UnicodeUTF8))
        self.actionHelp.setText(QtGui.QApplication.translate("MainWindow", "Help", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAbput.setText(QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSetup.setText(QtGui.QApplication.translate("MainWindow", "Setup...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSetup.setWhatsThis(QtGui.QApplication.translate("MainWindow", "Setup processing information", None, QtGui.QApplication.UnicodeUTF8))
        self.actionImageIn.setText(QtGui.QApplication.translate("MainWindow", "Import Image...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionImageIn.setWhatsThis(QtGui.QApplication.translate("MainWindow", "Import images", None, QtGui.QApplication.UnicodeUTF8))
        self.actionImportVector.setText(QtGui.QApplication.translate("MainWindow", "Import Vector Maps...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionImportVector.setWhatsThis(QtGui.QApplication.translate("MainWindow", "Import vector maps", None, QtGui.QApplication.UnicodeUTF8))
        self.actionQuit.setText(QtGui.QApplication.translate("MainWindow", "Quit", None, QtGui.QApplication.UnicodeUTF8))
        self.actionZoomIn.setText(QtGui.QApplication.translate("MainWindow", "Zoom In", None, QtGui.QApplication.UnicodeUTF8))
        self.actionZoomOut.setText(QtGui.QApplication.translate("MainWindow", "Zoom Out", None, QtGui.QApplication.UnicodeUTF8))
        self.actionProcessImages.setText(QtGui.QApplication.translate("MainWindow", "Process Images", None, QtGui.QApplication.UnicodeUTF8))
        self.actionFilterSet.setText(QtGui.QApplication.translate("MainWindow", "Filter Settings", None, QtGui.QApplication.UnicodeUTF8))
        self.actionFilter.setText(QtGui.QApplication.translate("MainWindow", "Filter", None, QtGui.QApplication.UnicodeUTF8))

import ui_resources_rc



class ProcessParameters( UserDict ):
    def __init__ (self, config_file='' ):
        """
        This class provide a consistent way to set and get all the
        parameters needed to process piv image files. It uses a 
        ConfigParser.SafeConfigParser, which bring some cool features, 
        like reading parameters from INI files.  COnfigParser is a 
        built-in python module. See its documentation for more details.
        
        To instantiate this class you may want to provide as an argument 
        a specific configuration file, but default values are already loaded
        as you create an instance.
        
        The optional file should be formatted like an INI file, with a unique 
        section named 'options'. Example:
        
        [options]
        initial_window_size = 32
        final_window_size = 32
        ...
    
        Parameters
        ----------
        
        config_file : string, optional
            an optional configuration file containing user setting 
            processing parameters.
            
        """
        
        # instantiate ancestor's class
        configparser = ConfigParser.SafeConfigParser()
        
        # read configuration files
        configparser.read( [openpiv.__default_config_file__, config_file] )
        
        UserDict.__init__(self, configparser.items('options') )
        
        # cast parameters to the right type.
        # this trick is necessary because the ConfigParser
        # class only understands strings
        for k, v in self.iteritems():
            try:
                self[k] = int(v)
            except ValueError:
                try:
                    self[k] = float(v)
                except ValueError:
                    pass
    
    def pretty_print ( self ):
        """
        Pretty print all the processing parameters.
        """
        for k, v in self.iteritems():
            print("%s = %s" % ( k.rjust(30), repr(v).ljust(30) ));

class Hdf5Database( ):
    """
    A class for writing/reading PIV data to an hdf5 file.
    
    This is currently work in progress, because it is not easy to 
    make parallel write to an hdf file with h5py.
    """
    def __init__ ( self, database, mode='create' ):
        """
        A database can be opened in read/create/modes.
        """

        if mode in [ 'create', 'c', 'w']:
            try:
                self._fh = h5py.File( database, mode='w-' )
            except:
                msg = "A file names %s already exists in folder %s. Delete it first if you really want to." % ( os.path.basename(database), os.path.dirname(database) )
                raise IOError(msg)
        elif mode in [ 'read', 'r']:
            self._fh = h5py.File( os.path.abspath(database), mode='r' )
        else:
            raise ValueError('wrong mode. create of read are accepted')
            
        # two groups for the two velocity components
        self._fh.create_group('/u')
        self._fh.create_group('/v')

    def write_coordinates( self, x, y ):
        """
        Write two datasets with the coordinates of the PIV vectors
        """
        self._fh.create_dataset ( 'x', data = x )
        self._fh.create_dataset ( 'y', data = y )

    def write_velocity_field ( self, i, u, v ):
        """
        Write datasets for the two velocity components.
        """
        self._fh.create_dataset ( '/u/field%05d' % i, data = u )
        self._fh.create_dataset ( '/v/field%05d' % i, data = v )

    def close ( self ):
        """Close file"""
        self._fh.close()





#!/usr/bin/env python
"""Scaling utilities
"""

__licence__ = """
Copyright (C) 2011  www.openpiv.net

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""


import numpy as np


def uniform( x, y, u, v, scaling_factor ):
    """
    Apply an uniform scaling
    
    Parameters
    ----------
    x : 2d np.ndarray
    
    y : 2d np.ndarray
    
    u : 2d np.ndarray
    
    v : 2d np.ndarray
    
    scaling_factor : float
        the image scaling factor in pixels per meter
    
    Return
    ----------
    x : 2d np.ndarray
    
    y : 2d np.ndarray
    
    u : 2d np.ndarray
    
    v : 2d np.ndarray
        
    """
    return x/scaling_factor, y/scaling_factor, u/scaling_factor, v/scaling_factor



#!/usr/bin/env python
import sys

if 'OpenPIV' not in sys.path:
    sys.path.append('/Users/alex/Documents/OpenPIV/alexlib/openpiv-python')

from openpiv import tools, validation, process, filters, scaling, pyprocess
import numpy as np
import matplotlib.pyplot as plt

frame_a  = tools.imread('exp1_001_a.bmp')
frame_b  = tools.imread('exp1_001_b.bmp' )


frame_a = frame_a[:128,:128]
frame_b = frame_b[:128,:128]

from pylab import *
imshow(np.c_[frame_a,frame_b],cmap=cm.gray)
show()


u, v, sig2noise = process.extended_search_area_piv(
    frame_a.astype(np.int32), 
    frame_b.astype(np.int32), 
    window_size=24, overlap=12, 
    dt=0.02, search_area_size=32, 
    sig2noise_method='peak2peak' )

x, y = process.get_coordinates( image_size=frame_a.shape, window_size=24, overlap=12 )


plt.figure()
plt.quiver(x,y,u,v)
plt.show()


u, v, s2n = pyprocess.piv( frame_a, frame_b, corr_method='fft', 
                            window_size=32, overlap=12, dt=0.02, sig2noise_method='peak2peak' )
x, y = pyprocess.get_coordinates( image_size=frame_a.shape, window_size=32, overlap=12 )

plt.figure()
plt.quiver(x,y,u,v)
plt.show()


u, v, s2n = pyprocess.piv( frame_a, frame_b, corr_method='direct', 
                            window_size=24, overlap=12, dt=0.02, 
                            sig2noise_method='peak2peak',
                            search_size = 32)
x, y = pyprocess.get_coordinates( image_size=frame_a.shape, 
                                         window_size=24, overlap=12 )

plt.figure()
plt.quiver(x,y,u,v)
plt.show()


#!/usr/bin/env python
"""
Copyright (C) 2011  www.openpiv.net

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from PySide import QtGui

import ui_mainwindow 

class MainWindow(QtGui.QMainWindow, ui_mainwindow.Ui_MainWindow):
    def __init__(self, parent=None):
        super(MainWindow, self).__init__(parent)
        self.setupUi(self)
        
